@@ -4,7 +4,11 @@ import pydantic.json
 
 
 def json_serializer(*args, **kwargs) -> str:
-    """Encodes json in the same way that pydantic does."""
+    """
+    Encodes json in the same way that pydantic does.
+    https://pydantic-docs.helpmanual.io/usage/dataclasses/#json-dumping
+    """
+
     return json.dumps(
         *args,
         default=pydantic.json.pydantic_encoder,
